#include <stdio.h>
#include <stdlib.h>
#include <stdbool.h>

#include <kirmes/kirmes.h>

int main(int argc, char *argv[])
{
    struct KirmesUserRecord *records = NULL;
    size_t num_records = 0;
    enum KirmesStatus status;
    size_t i;
    char *user = NULL;

    if (argc == 2) {
        user = argv[1];
    }

    status = kirmes_get_user_record(NULL,
                                    user,
                                    "io.systemd.Multiplexer",
                                    &records,
                                    &num_records);
    if (status != KirmesStatusSuccess) {
        fprintf(stderr, "Failed to get user record: %u\n", status);
        return EXIT_FAILURE;
    }

    for (i = 0;i < num_records;i++) {
        struct KirmesUserRecord record = records[i];
        size_t j;

        printf("User Name: %s\n", record.user_name);
        printf("UID:       %u\n", record.uid);
        printf("GID:       %u\n", record.gid);
        printf("Directory: %s\n", record.home_directory);
        printf("Shell:     %s\n", record.shell);
        if (record.member_of.size > 0) {
            bool first = true;

            printf("Groups:    ");
            for (j = 0; j < record.member_of.size; j++) {
                const char *group = record.member_of.vec[j];
                if (first) {
                    printf("%s\n", group);
                    first = false;
                } else {
                    printf("           %s\n", group);
                }
            }
        }
        if (record.environment.size > 0) {
            bool first = true;

            printf("Env:       ");
            for (j = 0; j < record.environment.size; j++) {
                const char *k = record.environment.vec[j].key;
                const char *v = record.environment.vec[j].val;
                if (first) {
                    printf("%s: %s\n", k, v);
                    first = false;
                } else {
                    printf("           %s: %s\n", k, v);
                }
            }
        }
        if (record.status.size > 0) {
            printf("service:   %s\n", record.status.vec[0].service);
        }
        printf("\n");
    }

    kirmes_user_record_free(records);

    return EXIT_SUCCESS;
}
